﻿/********************************************************************
	created:	2014/12/11
	created:	11:12:2014   19:24
	filename: 	CommonPlatform\Server\ServerInstance\CommonLib\Protocols\ProtoScene.cs
	file path:	CommonPlatform\Server\ServerInstance\CommonLib\Protocols
	file base:	ProtoScene
	file ext:	cs
	author:		刘冰生
	
	purpose:    Protocol for Login Module 
*********************************************************************/
using ProtoBuf;
using System;

namespace Protocols {

    /// <summary>
    /// 客户端类型
    /// </summary>
    public enum EClientType {
        Null = 0,
        Game = 1,   // 游戏端
        Gm = 2,     // GM后台
        Agent = 3,  // 代理后台
    }

    /// <summary>
    /// 账号类型
    /// </summary>
    public enum EAccountType {
        Null = 0,
        Player = 1, //普通玩家
        Gm = 2,     //GM后台
        Agent = 3,  //代理
        Robot = 4,
    }

    /// <summary>
    /// 用户注册请求
    /// </summary>
    [ProtoContract]
    public class UserRegisterReq : ProtoBody {
        [ProtoMember(1)] public string account = "";
        [ProtoMember(2)] public string password = "";
        [ProtoMember(3)] public string nickName = "";
        [ProtoMember(4)] public ERoleSex roleSex = ERoleSex.Boy;
    }

    /// <summary>
    /// 用户注册返回
    /// </summary>
    [ProtoContract]
    public class UserRegisterRsp : ProtoBody {
        public enum ErrorID : uint {
            //成功
            Success = 0,
            //失败
            Failed = 1,
            //该账号已经存在
            AlreadyExist = 2,
            //该昵称已存在
            AlreadyNickName = 3,
            //账号为空
            AccountIsNull = 4,
            //密码为空
            PasswordIsNull = 5,
            //昵称为空
            NickNameIsNull = 6,
        }

        [ProtoMember(1)]
        public ErrorID errorID;
    }

    /// <summary>
    /// 用户登录请求
    /// </summary>
    [ProtoContract]
    public class UserLoginReq : ProtoBody {
        [ProtoMember(1)] public EPID platformType = EPID.Internal;
        //自有平台账号
        [ProtoMember(2)] public string account = "";
        //自有平台密码
        [ProtoMember(3)] public string password = "";
        //使用accountId登录
        [ProtoMember(5)] public ulong accountId = 0;
    }

    /// <summary>
    /// 用户登录返回
    /// </summary>
    [ProtoContract]
    public class UserLoginRsp : ProtoBody {
        public enum ErrorID : uint {
            [EnumDescription("成功")] Success = 0,
            [EnumDescription("失败")] Failed = 1,
            [EnumDescription("密码错误")] PassWord_Wrong = 2,
            [EnumDescription("该账号正在其他设备上登录")] AccountDuplicateLogin = 3,
            [EnumDescription("账号不存在")] AccountNotExist = 4,
            [EnumDescription("没有权限")] NotAgentOrGm = 5,
            [EnumDescription("账号停用中")] AccountStopUseing = 6,
        }

        [ProtoMember(1)] public ErrorID errorID;
        //gate重连时的内部token
        [ProtoMember(2)] public string gateInnerToken = "";
        //服务器配置
        [ProtoMember(3)] public stServerConfig serverConfig = new stServerConfig();
        //玩家状态
        // [ProtoMember(4)] public stPlayerStatus playerStatus = new stPlayerStatus();
    }

    /// <summary>
    /// 获取服务器时间
    /// </summary>
    [ProtoContract]
    public class GetServerTimeReq : ProtoBody {
        [ProtoMember(1)] public double clientTime = 0;
    }

    /// <summary>
    /// 获取服务器时间
    /// </summary>
    [ProtoContract]
    public class GetServerTimeRsp : ProtoBody {
        [ProtoMember(1)] public double serverTime = 0;
    }

    ///// <summary>
    ///// 上传GIF
    ///// </summary>
    //[ProtoContract]
    //public class UploadGifReq : ProtoBody {
    //    //图片数据
    //    [ProtoMember(1)] public string datas = "";
    //}

    /// <summary>
    /// 上传GIF
    /// </summary>
    [ProtoContract]
    public class UploadGifRsp : ProtoBody {
        public enum ErrorID : uint {
            //成功
            Success = 0,
            //失败
            Failed = 1,
        }

        //[ProtoMember(1)] public ErrorID errorID = 0;
        ////上传成功路径
        //[ProtoMember(2)] public string path = "";
    }
}